#!/bin/bash
# Setup for Dawicontrol DC-600e/610e RAID driver
# needs DKMS installed

target=dc600e
version=5.38.01

destdir=/usr/src/$target-$version
headerdir=/lib/modules/`uname -r`/build

# welcome

echo
echo "--------------------------------------------"
echo " Dawicontrol DC-600e/610e RAID driver setup "
echo "--------------------------------------------"
echo
echo "This setup script will"
echo "- copy all sourcefiles to $destdir"
echo "- add the driver to DKMS"
echo "- build the driver by DKMS"
echo "- install the driver by DKMS"
echo
read -s -n1 -p "Press any key to continue, or ESC to abort..." key; echo
case $key in
        $'\e') exit 1;;
esac
echo

# verify root privileges

if [ $(id -u) != 0 ]; then
        echo "Abort: no root privileges."
        exit 1
fi

# verify sourcefiles

if [ ! -f $target"_.c" ] ||
   [ ! -f $target"_x64.o_shipped" ] ||
   [ ! -f "dcmodule.c" ] ||
   [ ! -f "dcmodule.h" ] ||
   [ ! -f "Makefile" ] ||
   [ ! -f "dkms.conf" ]; then
        echo "Abort: sourcefiles incomplete."
        exit 1
fi;

# verify build essentials

if ! type make >/dev/null 2>&1 ||
   ! type gcc >/dev/null 2>&1 ||
   ! type ld >/dev/null 2>&1 ; then
        echo "Abort: build essentials not installed."
        exit 1
fi

# verify kernel headerfiles

if [ ! -d "$headerdir" ]; then
        echo "Abort: kernel-headers not installed."
        exit 1
fi

# verify DKMS

if ! type dkms >/dev/null 2>&1; then
        echo "Abort: DKMS not installed."
        exit 1
fi

# copy files to DKMS destination directory

if [ ! -d "$destdir" ]; then
        mkdir $destdir
fi
cp -f * $destdir

# add to DKMS

dkms add -m $target -v $version
if [ $? -ne 0 ]; then
        exit 1
fi

# build driver

dkms build -m $target -v $version
if [ $? -ne 0 ]; then
        exit 1
fi

# install driver

dkms install --force -m $target -v $version
if [ $? -eq 0 ]; then
        echo "Installation complete."
        echo "Run 'modprobe $target' to load the driver, then"
        echo "open '/proc/$target' or run 'dmesg' to check."
fi

exit
#!/bin/bash
# Setup for Dawicontrol DC-600e/610e RAID driver
# needs DKMS installed

target=dc600e
version=5.37.00

destdir=/usr/src/$target-$version
headerdir=/lib/modules/`uname -r`/build

# welcome

echo
echo "--------------------------------------------"
echo " Dawicontrol DC-600e/610e RAID driver setup "
echo "--------------------------------------------"
echo
echo "This setup script will"
echo "- copy all sourcefiles to $destdir"
echo "- add the driver to DKMS"
echo "- build the driver by DKMS"
echo "- install the driver by DKMS"
echo
read -s -n1 -p "Press any key to continue, or ESC to abort..." key; echo
case $key in
        $'\e') exit 1;;
esac
echo

# verify root privileges

if [ $(id -u) != 0 ]; then
        echo "Abort: no root privileges."
        exit 1
fi

# verify sourcefiles

if [ ! -f $target"_.c" ] ||
   [ ! -f $target"_x64.o_shipped" ] ||
   [ ! -f "dcmodule.c" ] ||
   [ ! -f "dcmodule.h" ] ||
   [ ! -f "Makefile" ] ||
   [ ! -f "dkms.conf" ]; then
        echo "Abort: sourcefiles incomplete."
        exit 1
fi;

# verify build essentials

if ! type make >/dev/null 2>&1 ||
   ! type gcc >/dev/null 2>&1 ||
   ! type ld >/dev/null 2>&1 ; then
        echo "Abort: build essentials not installed."
        exit 1
fi

# verify kernel headerfiles

if [ ! -d "$headerdir" ]; then
        echo "Abort: kernel-headers not installed."
        exit 1
fi

# verify DKMS

if ! type dkms >/dev/null 2>&1; then
        echo "Abort: DKMS not installed."
        exit 1
fi

# copy files to DKMS destination directory

if [ ! -d "$destdir" ]; then
        mkdir $destdir
fi
cp -f * $destdir

# add to DKMS

dkms add -m $target -v $version
if [ $? -ne 0 ]; then
        exit 1
fi

# build driver

dkms build -m $target -v $version
if [ $? -ne 0 ]; then
        exit 1
fi

# install driver

dkms install --force -m $target -v $version
if [ $? -eq 0 ]; then
        echo "Installation complete."
        echo "Run 'modprobe $target' to load the driver, then"
        echo "open '/proc/$target' or run 'dmesg' to check."
fi

exit
